@@ -17,7 +17,10 @@ def parse_pdf(path, citation, key, chunk_chars=2000, overlap=50):
     for i, page in enumerate(pdfReader.pages):
         split += page.extract_text()
         pages.append(str(i + 1))
-        if len(split) > chunk_chars:
+        # split could be so long it needs to be split
+        # into multiple chunks. Or it could be so short
+        # that it needs to be combined with the next chunk.
+        while len(split) > chunk_chars:
             splits.append(split[:chunk_chars])
             # pretty formatting of pages (e.g. 1-3, 4, 5-7)
             pg = "-".join([pages[0], pages[-1]])
@@ -31,7 +34,7 @@ def parse_pdf(path, citation, key, chunk_chars=2000, overlap=50):
             split = split[chunk_chars - overlap :]
             pages = [str(i + 1)]
     if len(split) > overlap:
-        splits.append(split)
+        splits.append(split[:chunk_chars])
         pg = "-".join([pages[0], pages[-1]])
         metadatas.append(
             dict(
@@ -81,7 +84,7 @@ def parse_code_txt(path, citation, key, chunk_chars=2000, overlap=50):
                 split = split[chunk_chars - overlap :]
                 last_line = i
     if len(split) > overlap:
-        splits.append(split)
+        splits.append(split[:chunk_chars])
         metadatas.append(
             dict(
                 citation=citation,
@@ -92,7 +95,7 @@ def parse_code_txt(path, citation, key, chunk_chars=2000, overlap=50):
     return splits, metadatas
 
 
-def read_doc(path, citation, key, chunk_chars=2000, overlap=50, disable_check=False):
+def read_doc(path, citation, key, chunk_chars=3000, overlap=100, disable_check=False):
     """Parse a document into chunks."""
     if path.endswith(".pdf"):
         return parse_pdf(path, citation, key, chunk_chars, overlap)
